@@ -177,16 +177,12 @@ static NSMapTable	*docMap = 0;
       && [[document nameForObject: selected] isEqualToString: @"NSOwner"] == NO
       && [[document nameForObject: selected] isEqualToString: @"NSFirst"] == NO)
     {
-      NSNotificationCenter	*nc;
-
-      nc = [NSNotificationCenter defaultCenter];
-
       if ([selected isKindOfClass: [NSMenu class]] &&
 	  [[document nameForObject: selected] isEqual: @"NSMenu"] == YES)
 	{
 	  NSString *title = _(@"Removing Main Menu");
 	  NSString *msg = _(@"Are you sure you want to do this?");
-	  int retval = NSRunAlertPanel(title, msg,_(@"OK"),_(@"Cancel"), nil, nil);
+	  NSInteger retval = NSRunAlertPanel(title, msg,_(@"OK"),_(@"Cancel"), nil, nil);
 	  
 	  // if the user *really* wants to delete the menu, do it.
 	  if(retval != NSAlertDefaultReturn)
